==> opensearch-dashboards-2.16.0.tgz: opensearch-dashboards/src/core/utils/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "ALL_USE_CASE_ID", {
  enumerable: true,
  get: function () {
    return _default_nav_groups.ALL_USE_CASE_ID;
  }
});
Object.defineProperty(exports, "ContextContainer", {
  enumerable: true,
  get: function () {
    return _context.ContextContainer;
  }
});
Object.defineProperty(exports, "DEFAULT_APP_CATEGORIES", {
  enumerable: true,
  get: function () {
    return _default_app_categories.DEFAULT_APP_CATEGORIES;
  }
});
Object.defineProperty(exports, "DEFAULT_NAV_GROUPS", {
  enumerable: true,
  get: function () {
    return _default_nav_groups.DEFAULT_NAV_GROUPS;
  }
});
Object.defineProperty(exports, "HandlerContextType", {
  enumerable: true,
  get: function () {
    return _context.HandlerContextType;
  }
});
Object.defineProperty(exports, "HandlerFunction", {
  enumerable: true,
  get: function () {
    return _context.HandlerFunction;
  }
});
Object.defineProperty(exports, "HandlerParameters", {
  enumerable: true,
  get: function () {
    return _context.HandlerParameters;
  }
});
Object.defineProperty(exports, "IContextContainer", {
  enumerable: true,
  get: function () {
    return _context.IContextContainer;
  }
});
Object.defineProperty(exports, "IContextProvider", {
  enumerable: true,
  get: function () {
    return _context.IContextProvider;
  }
});
Object.defineProperty(exports, "WORKSPACE_PATH_PREFIX", {
  enumerable: true,
  get: function () {
    return _constants.WORKSPACE_PATH_PREFIX;
  }
});
Object.defineProperty(exports, "WORKSPACE_TYPE", {
  enumerable: true,
  get: function () {
    return _constants.WORKSPACE_TYPE;
  }
});
Object.defineProperty(exports, "cleanWorkspaceId", {
  enumerable: true,
  get: function () {
    return _workspace.cleanWorkspaceId;
  }
});
Object.defineProperty(exports, "formatUrlWithWorkspaceId", {
  enumerable: true,
  get: function () {
    return _workspace.formatUrlWithWorkspaceId;
  }
});
Object.defineProperty(exports, "getWorkspaceIdFromUrl", {
  enumerable: true,
  get: function () {
    return _workspace.getWorkspaceIdFromUrl;
  }
});
var _context = require("./context");
var _default_app_categories = require("./default_app_categories");
var _constants = require("./constants");
var _workspace = require("./workspace");
var _default_nav_groups = require("./default_nav_groups");

==> opensearch-dashboards-2.19.1.tgz: opensearch-dashboards/src/core/utils/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "ALL_USE_CASE_ID", {
  enumerable: true,
  get: function () {
    return _default_nav_groups.ALL_USE_CASE_ID;
  }
});
Object.defineProperty(exports, "ContextContainer", {
  enumerable: true,
  get: function () {
    return _context.ContextContainer;
  }
});
Object.defineProperty(exports, "DEFAULT_APP_CATEGORIES", {
  enumerable: true,
  get: function () {
    return _default_app_categories.DEFAULT_APP_CATEGORIES;
  }
});
Object.defineProperty(exports, "DEFAULT_NAV_GROUPS", {
  enumerable: true,
  get: function () {
    return _default_nav_groups.DEFAULT_NAV_GROUPS;
  }
});
Object.defineProperty(exports, "ESSENTIAL_USE_CASE_ID", {
  enumerable: true,
  get: function () {
    return _default_nav_groups.ESSENTIAL_USE_CASE_ID;
  }
});
Object.defineProperty(exports, "HandlerContextType", {
  enumerable: true,
  get: function () {
    return _context.HandlerContextType;
  }
});
Object.defineProperty(exports, "HandlerFunction", {
  enumerable: true,
  get: function () {
    return _context.HandlerFunction;
  }
});
Object.defineProperty(exports, "HandlerParameters", {
  enumerable: true,
  get: function () {
    return _context.HandlerParameters;
  }
});
Object.defineProperty(exports, "IContextContainer", {
  enumerable: true,
  get: function () {
    return _context.IContextContainer;
  }
});
Object.defineProperty(exports, "IContextProvider", {
  enumerable: true,
  get: function () {
    return _context.IContextProvider;
  }
});
Object.defineProperty(exports, "OBSERVABILITY_USE_CASE_ID", {
  enumerable: true,
  get: function () {
    return _default_nav_groups.OBSERVABILITY_USE_CASE_ID;
  }
});
Object.defineProperty(exports, "SEARCH_USE_CASE_ID", {
  enumerable: true,
  get: function () {
    return _default_nav_groups.SEARCH_USE_CASE_ID;
  }
});
Object.defineProperty(exports, "SECURITY_ANALYTICS_USE_CASE_ID", {
  enumerable: true,
  get: function () {
    return _default_nav_groups.SECURITY_ANALYTICS_USE_CASE_ID;
  }
});
Object.defineProperty(exports, "WORKSPACE_PATH_PREFIX", {
  enumerable: true,
  get: function () {
    return _constants.WORKSPACE_PATH_PREFIX;
  }
});
Object.defineProperty(exports, "WORKSPACE_TYPE", {
  enumerable: true,
  get: function () {
    return _constants.WORKSPACE_TYPE;
  }
});
Object.defineProperty(exports, "cleanWorkspaceId", {
  enumerable: true,
  get: function () {
    return _workspace.cleanWorkspaceId;
  }
});
Object.defineProperty(exports, "formatUrlWithWorkspaceId", {
  enumerable: true,
  get: function () {
    return _workspace.formatUrlWithWorkspaceId;
  }
});
Object.defineProperty(exports, "getWorkspaceIdFromUrl", {
  enumerable: true,
  get: function () {
    return _workspace.getWorkspaceIdFromUrl;
  }
});
var _context = require("./context");
var _default_app_categories = require("./default_app_categories");
var _constants = require("./constants");
var _workspace = require("./workspace");
var _default_nav_groups = require("./default_nav_groups");
